//
//  StatementViewController.m
//  RealEstateManagement
//
//  Created by Z on 16/6/29.
//  Copyright © 2016年 上海勾芒信息科技. All rights reserved.
//

#import "StatementViewController.h"
#import "StatementTableViewCell.h"
#import "NSDate+FormatterAdditions.h"
#import "SRMonthPicker.h"
#import "StatementListParamModel.h"
#import "StatementModel.h"
#import "VankeAppBoard_iPhone.h"

@interface StatementViewController ()<UITableViewDelegate, UITableViewDataSource, SRMonthPickerDelegate, UISearchBarDelegate>
@property (weak, nonatomic) IBOutlet UITableView *tableView;
/** 共?家商铺 */
@property (weak, nonatomic) IBOutlet UILabel *labelTotalShop;
/** 应缴合计 */
@property (weak, nonatomic) IBOutlet UILabel *labelTotalShouldPay;
/** 已缴合计 */
@property (weak, nonatomic) IBOutlet UILabel *labelTotalPaidIn;
/** 未缴合计 */
@property (weak, nonatomic) IBOutlet UILabel *labelTotalUnPaid;
/** 输入框，用于呼出datePicker */
@property (weak, nonatomic) IBOutlet UITextField *textFieldSelectDate;
/** 年 */
@property (weak, nonatomic) IBOutlet UILabel *labelYear;
/** 月 */
@property (weak, nonatomic) IBOutlet UILabel *labelMonth;
/** 输入框 用于呼出datePicker */
@property (weak, nonatomic) IBOutlet UITextField *finishTextField;
/** 截止 年 */
@property (weak, nonatomic) IBOutlet UILabel *labelFinishYear;
/** 截止 月 */
@property (weak, nonatomic) IBOutlet UILabel *labelFinishMonth;
@property (weak, nonatomic) IBOutlet UISearchBar *searchBar;
/** 当前选中的日期 */
@property (nonatomic, copy) NSString *startDate;
@property (nonatomic, copy) NSString *endDate;

/** 网络请求参数 */
@property (nonatomic, strong) StatementListParamModel *paramModel;

@property (nonatomic, strong) NSMutableArray *arrData;
@end

@implementation StatementViewController

- (void)viewDidLoad {
    [super viewDidLoad];
     [[VankeAppBoard_iPhone sharedInstance] hideMenu];
    [self setDefaults];
    [self setUpDatePicker];
    self.paramModel = [[StatementListParamModel alloc] init];
    self.title = @"商铺对账单";
//    self.paramModel.authorizedOrgIn = [[UserInfo shareInstance].authorizedOrgs[0] uuid];
    self.paramModel.pageSize = 999;
    self.paramModel.pageNumber = 0;
    [self setUpData];
    // Do any additional setup after loading the view.
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
   
//    self.navigationController.navigationBar.barTintColor = kMainPurpleColor;
}

- (void)setDefaults {
    NSDate *currentDate = [NSDate date];
    self.startDate = currentDate.yearMonthString;
    self.endDate = [currentDate stringWithFormatter:@"%Y%m"];
    self.labelYear.text = currentDate.yearString;
    self.labelMonth.text = currentDate.monthString;
    self.labelFinishYear.text = currentDate.yearString;
    self.labelFinishMonth.text = currentDate.monthString;
}

- (void)setUpDatePicker {
    SRMonthPicker *datePicker = [[SRMonthPicker alloc] initWithDate:[NSDate date]];
    datePicker.monthPickerDelegate = self;
    datePicker.yearFirst = YES;
    self.textFieldSelectDate.inputView = datePicker;
    self.finishTextField.inputView = datePicker;
}

/** 显示结清账户 */
- (IBAction)showSettleShop:(UIButton *)sender {
    sender.selected = !sender.isSelected;
}

#pragma mark - SRMonthPickerDelegate
- (void)monthPickerDidChangeDate:(SRMonthPicker *)monthPicker {
    NSString *strDate = monthPicker.date.yearMonthString;
    NSString *year = monthPicker.date.yearString;
    NSString *month = monthPicker.date.monthString;
    //判断是开始时间还是结束时间
    if ([self.textFieldSelectDate isFirstResponder]) {
        self.startDate = strDate;
        self.labelYear.text = year;
        self.labelMonth.text = month;
    }else{
        self.endDate = strDate;
        self.labelFinishYear.text = year;
        self.labelFinishMonth.text = month;
    }
}

#pragma mark - UISearchBarDelegate
- (BOOL)searchBarShouldBeginEditing:(UISearchBar *)searchBar {
    searchBar.showsCancelButton = YES;
    return YES;
}

- (void)searchBarCancelButtonClicked:(UISearchBar *)searchBar {
    searchBar.showsCancelButton = NO;
    searchBar.text = nil;
    HIDE_KEYBOARD;
}

- (void)searchBarSearchButtonClicked:(UISearchBar *)searchBar {
    searchBar.showsCancelButton = NO;
    HIDE_KEYBOARD;
}

/** 网络请求 */
- (void)setUpData {
    
    NSString *url = [NSString stringWithFormat:@"statement/query/%@~%@?authorizedOrgIn=%@&pageNumber=%@&pageSize=%@", @"201509", self.endDate, self.org.code, @0, @999];
    WS(weakSelf);
    [[ICRHTTPController sharedController] getUrl:url params:nil success:^(id data) {
        NSDictionary *dict = data;
        CLog(@"%@", dict.JSONString);
        NSInteger count = dict[@"paging"][@"recordCount"];
        weakSelf.labelTotalShop.text = [NSString stringWithFormat:@"%ld",(long)count];
        for (NSDictionary *dic in data[@"data"][@"records"]) {
            [self.arrData addObject:[StatementModel modelObjectWithDictionary:dic]];
        }
        [self.tableView reloadData];
    } failure:^(id data) {
        
    }];

    
   
}

#pragma mark - tableView DataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.arrData.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    StatementTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"StatementCell" forIndexPath:indexPath];
    [cell setUpCellWithArray:self.arrData index:indexPath];
    return cell;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 90;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [self PushToStoryBoardVCWithIdentifier:@"StatementDetailViewController" isHideTabbar:YES animate:YES];
}

- (NSMutableArray *)arrData {
    if (!_arrData) {
        _arrData = [NSMutableArray array];
    }
    return _arrData;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
